@@ -403,7 +403,7 @@ def MakeProfiles(ClustersFileName="VicinityPermissiveClustsLinear" + "RM_A" + ".
             pool.join()
 
 
-    if __name__ == "Loupe":
+    if __name__ == "LoupeTool.Loupe":
         t1 = time.time()
         cnt = 0
 
